import { css } from "@linaria/core";
import { defineComponent, onMounted, reactive, ref } from "vue";
import { string } from "vue-types";
import { useEditor } from "../../..";

export const View = defineComponent({
  props: {
    bgSrc: string(),
  },
  setup(props, { slots }) {
    const { store, actions } = useEditor();
    const viewRef = ref<HTMLElement>();
    const state = reactive({
      compId: "",
    });
    onMounted(() => {
      const compEl = viewRef.value;
      state.compId = compEl?.getAttribute("data-id") || "";
    });
    return () => {
      const isComp = state.compId;
      const isSelected = store.isEditMode && store.currCompId === state.compId;

      const styleObj: any = {};
      if (props.bgSrc) {
        styleObj["--view-bg-src"] = `url(${props.bgSrc})`;
      }

      return (
        <div
          ref={viewRef}
          class={[
            store.isEditMode && isComp ? viewStyle : "view_inside",
            store.isEditMode && isSelected && "view_selected",
            props.bgSrc && viewBgStyle,
          ]}
          style={styleObj}
          onClick={
            state.compId
              ? () => {
                  if (state.compId !== store.currCompId)
                    actions.pickCurrComp(state.compId);
                }
              : undefined
          }
        >
          {slots.default?.()}
        </div>
      );
    };
  },
});

const viewBgStyle = css`
  background-image: var(--view-bg-src);
`;

const viewStyle = css`
  position: relative;
  &:hover {
    outline: 1px dashed @inf-primary-color;
  }

  > * {
    pointer-events: none;
  }

  &.view_selected {
    outline: 1px solid @inf-primary-color;

    > * {
      pointer-events: auto;
    }
    &::after {
      display: none;
    }

    .view_inside:hover {
      outline: 1px dashed @inf-primary-color;
      outline-offset: -1px;
    }
  }

  .view_inside {
    position: relative;
  }
`;
