import { defineUI } from "queenjs";
import { onUnmounted } from "vue";
import { Container, Draggable } from "vue-dndrop";
import { useEditor } from "../../..";
import { HotKeyCtrl } from "../../../controllers/HotKeyCtrl";
import Canvas from "../../Canvas";

export default defineUI({
  setup() {
    const editor = useEditor();
    const { store, components, actions } = editor;

    const hotKeyCtrl = new HotKeyCtrl(editor);
    hotKeyCtrl.init();
    onUnmounted(() => {
      hotKeyCtrl.destroy();
    });

    return () => (
      <div class="min-h-750px bg-white">
        {store.isEditMode ? (
          <Container
            style={store.designData.pageStyle}
            onDrop={(e: any) => actions.moveComp(e.removedIndex, e.addedIndex)}
          >
            {store.designData.content.map((d) => {
              const Comp = components.CompUI[d.compKey];
              return (
                <Draggable key={d.id}>
                  <Comp
                    class="draggable-item"
                    data-id={d.id}
                    {...(d.props || {})}
                    style={d.style}
                    v-model={[d.value, "value"]}
                  />
                </Draggable>
              );
            })}
          </Container>
        ) : (
          <Canvas />
        )}
      </div>
    );
  },
});
