import { useResource } from "@/modules/resource";
import { List } from "@queenjs/ui";
import { Button, Empty } from "ant-design-vue";
import { queenApi, useModal } from "queenjs";
import { defineComponent, reactive } from "vue";

export default defineComponent({
  setup() {
    const resource = useResource();
    const modal = useModal();

    const state = reactive({
      list: [],
    }) as any;

    const submit = () => {
      if (state.list.length == 0) {
        queenApi.messageError("请选择至少一个模板");
        return;
      }
      resource.actions.submitRender();
    };

    return () => {
      return (
        <div>
          <List data={resource.store.sourceDetail.images} columns={5}>
            {{
              item: (record: any) => {
                return (
                  <resource.components.MaterialItem
                    record={record}
                    class="cursor-pointer"
                    active={state.list.includes(record.id)}
                    onSelect={() => {
                      if (state.list.includes(record.id)) {
                        const index = state.list.findIndex(
                          (d: string) => d == record.id
                        );
                        state.list.splice(index);
                        return;
                      }
                      state.list.push(record.id);
                    }}
                  />
                );
              },
              empty: () => <Empty description="暂无数据" />,
            }}
          </List>

          <div class="text-right">
            <Button onClick={modal.cancel}>取消</Button>
            <Button type="primary" class="ml-20px" onClick={submit}>
              确定
            </Button>
          </div>
        </div>
      );
    };
  },
});
